# create_artisan_alarms_phidget

Create artisan profiles using the alarms and the modified version of the freshroastsr700 library for phidget

### Install with:

```pip install create_artisan_alarms_phidget```

If you have Python3 you may need to install with:

```pip3 install create_artisan_alarms_phidget```

### Then run with:

```create_artisan_alarms_phidget```

### This short video illustrate the setup and how to use this tool:

![](create_profile_demo.gif)
